%global common_description %{expand
The ppp package contains the PPP (Point-to-Point Protocol) daemon and
documentation for PPP support. The PPP protocol provides a method for
transmitting datagrams over serial point-to-point links. PPP is
usually used to dial in to an ISP (Internet Service Provider) or other
organization over a modem and phone line.}

Summary:       The Point-to-Point Protocol daemon
Name:          ppp
Version:       2.5.0
Release:       6%{?dist}
License:       BSD and LGPLv2+ and GPLv2+ and Public Domain
URL:           http://www.samba.org/ppp
Source0:       https://github.com/paulusmack/ppp/archive/ppp-%{version}.tar.gz
Source1:       ppp-pam.conf
Source2:       ppp-logrotate.conf
Source3:       ppp-tmpfiles.conf
Source4:       ip-down
Source5:       ip-down.ipv6to4
Source6:       ip-up
Source7:       ip-up.ipv6to4
Source8:       ipv6-down
Source9:       ipv6-up
Source10:      ifup-ppp
Source11:      ifdown-ppp
Source12:      ppp-watch.tar.xz

Patch1:        CVE-2024-58250.patch

Patch3000:     ppp-2.5.0-use-change-resolv-function.patch

BuildRequires: make gcc openssl-devel systemd
BuildRequires: pam-devel libpcap-devel systemd-devel glib2-devel libtool
Requires:      glibc /etc/pam.d/system-auth libpcap systemd
Requires(pre): /usr/bin/getent
Requires(pre): /usr/sbin/groupadd

%description
%{common_description}

%package -n network-scripts-%{name}
Summary: PPP legacy network service support
Requires: network-scripts
Supplements: (%{name} and network-scripts)

%description -n network-scripts-%{name}
%{common_description}
This provides the ifup and ifdown scripts for use with the legacy network
service.

%package devel
Summary: Headers for ppp plugin development
Requires: %{name}%{?_isa} = %{version}-%{release}
Requires: pkgconf-pkg-config

%description devel
%{common_description}
This package contains the header files for building plugins for ppp.

%prep
%autosetup -p1 -n %{name}-%{name}-%{version}
tar -xJf %{SOURCE12}

%build
autoreconf -fi
export CFLAGS="%{build_cflags} -fno-strict-aliasing"
%configure --enable-systemd --enable-cbcp --with-pam
%make_build
%make_build -C ppp-watch LDFLAGS="%{?build_ldflags} -pie"

%install
%make_install
find scripts -type f | xargs chmod a-x
make ROOT=%{buildroot} -C ppp-watch install

install -d %{buildroot}%{_localstatedir}/log/ppp

install -Dm 644 %{SOURCE1} %{buildroot}%{_sysconfdir}/pam.d/ppp
install -Dm 644 -p %{SOURCE2} %{buildroot}%{_sysconfdir}/logrotate.d/ppp
install -Dm 644 -p %{SOURCE3} %{buildroot}%{_tmpfilesdir}/ppp.conf

install -d %{buildroot}%{_sysconfdir}/ppp
install -p %{SOURCE4} %{buildroot}%{_sysconfdir}/ppp/ip-down
install -p %{SOURCE5} %{buildroot}%{_sysconfdir}/ppp/ip-down.ipv6to4
install -p %{SOURCE6} %{buildroot}%{_sysconfdir}/ppp/ip-up
install -p %{SOURCE7} %{buildroot}%{_sysconfdir}/ppp/ip-up.ipv6to4
install -p %{SOURCE8} %{buildroot}%{_sysconfdir}/ppp/ipv6-down
install -p %{SOURCE9} %{buildroot}%{_sysconfdir}/ppp/ipv6-up

install -d %{buildroot}%{_sysconfdir}/sysconfig/network-scripts/
install -p %{SOURCE10} %{buildroot}%{_sysconfdir}/sysconfig/network-scripts/ifup-ppp
install -p %{SOURCE11} %{buildroot}%{_sysconfdir}/sysconfig/network-scripts/ifdown-ppp

install -d %{buildroot}%{_rundir}/ppp

%pre
/usr/bin/getent group dip >/dev/null 2>&1 || /usr/sbin/groupadd -r -g 40 dip >/dev/null 2>&1 || :

%post
%tmpfiles_create ppp.conf

%files
%doc FAQ README README.cbcp README.linux README.MPPE README.MSCHAP80 README.MSCHAP81 README.pwfd README.pppoe scripts sample README.eap-tls
%{_sbindir}/chat
%{_sbindir}/pppd
%{_sbindir}/pppdump
%{_sbindir}/pppoe-discovery
%{_sbindir}/pppstats
%{_sbindir}/ppp-watch
%dir %{_sysconfdir}/ppp
%{_sysconfdir}/ppp/ip-up
%{_sysconfdir}/ppp/ip-down
%{_sysconfdir}/ppp/ip-up.ipv6to4
%{_sysconfdir}/ppp/ip-down.ipv6to4
%{_sysconfdir}/ppp/ipv6-up
%{_sysconfdir}/ppp/ipv6-down
%{_sysconfdir}/ppp/openssl.cnf
%{_libdir}/pppd
%ghost %dir %{_rundir}/ppp
%dir %{_sysconfdir}/logrotate.d
%attr(700, root, root) %dir %{_localstatedir}/log/ppp
%config(noreplace) %{_sysconfdir}/ppp/eaptls-client
%config(noreplace) %{_sysconfdir}/ppp/eaptls-server
%config(noreplace) %{_sysconfdir}/ppp/chap-secrets
%config(noreplace) %{_sysconfdir}/ppp/options
%config(noreplace) %{_sysconfdir}/ppp/pap-secrets
%config(noreplace) %{_sysconfdir}/pam.d/ppp
%config(noreplace) %{_sysconfdir}/logrotate.d/ppp
%{_tmpfilesdir}/ppp.conf
%{_mandir}/man8/chat.8*
%{_mandir}/man8/pppd.8*
%{_mandir}/man8/pppdump.8*
%{_mandir}/man8/pppd-radattr.8*
%{_mandir}/man8/pppd-radius.8*
%{_mandir}/man8/pppstats.8*
%{_mandir}/man8/pppoe-discovery.8*
%{_mandir}/man8/ppp-watch.8*

%files -n network-scripts-%{name}
%{_sysconfdir}/sysconfig/network-scripts/ifdown-ppp
%{_sysconfdir}/sysconfig/network-scripts/ifup-ppp

%files devel
%doc PLUGINS
%{_includedir}/pppd
%{_libdir}/pkgconfig/pppd.pc

%changelog
* Fri May 23 2025 Xin Cheng <denisecheng@tencent.com> - 2.5.0-6
- fix CVE-2024-58250

* Mon Jan 20 2025 Xin Cheng <denisecheng@tencent.com> - 2.5.0-5
- add BuildRequires libtool

* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.5.0-4
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.5.0-3
- Rebuilt for loongarch release

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.5.0-2
- Rebuilt for OpenCloudOS Stream 23.09

* Tue Aug 22 2023 Wang Guodong <gordonwwang@tencent.com> - 2.5.0-1
- Upgrade to version 2.5.0

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.4.9-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.4.9-2
- Rebuilt for OpenCloudOS Stream 23

* Fri Nov 18 2022 Shuo Wang <abushwang@tencent.com> - 2.4.9-1
- initial build
